# 
# This file is part of Task-WebGUI
# 
# This software is copyright (c) 2010 by Patrick Donelan.
# 
# This is free software; you can redistribute it and/or modify it under
# the same terms as the Perl 5 programming language system itself.
# 
package Task::WebGUI;
BEGIN {
  $Task::WebGUI::VERSION = '1.101040';
}
# ABSTRACT: Install WebGUI dependencies


1;
__END__
=pod

=head1 NAME

Task::WebGUI - Install WebGUI dependencies

=head1 VERSION

version 1.101040

=head1 DESCRIPTION

Run the following to install all WebGUI dependencies:

 > cpanm Task::WebGUI

=head1 AUTHOR

  Patrick Donelan <pat@patspam.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2010 by Patrick Donelan.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

